@@ -1,5 +1,5 @@
 ## This code is part of the ips package
-## © C. Heibl 2014 (last update 2017-04-06)
+## © C. Heibl 2014 (last update 2021-04-04)
 
 #' @title Sequence Alignment with MAFFT
 #' @description This function is a wrapper for MAFFT and can be used for 
@@ -26,8 +26,9 @@
 #' @param ep A numeric giving the offset value, which works like \code{gap 
 #'   extension penalty}, for group-to-group alignment; default 0.0, but 0.123 is
 #'   recommended if no long indels are expected.
-#' @param gt An object of class \code{\link{phylo}} that is to be used as a 
-#'   guide tree during alignment.
+#' @param gt An object of class \code{\link{phylo}} that is to be used as a
+#'   guide tree during alignment. The default is to let MAFFT use its own
+#'   internal guide tree
 #' @param options A vector of mode character specifying additional arguments to 
 #'   MAFFT, that are not included in \code{mafft} such as, e.g., 
 #'   \code{--adjustdirection}.
@@ -72,7 +73,7 @@
 #'   method for rapid multiple sequence alignment based on fast Fourier 
 #'   transform. \emph{Nucleid Acids Research} \bold{30}: 3059--3066.
 #'   
-#'   \url{http://mafft.cbrc.jp/alignment/software/index.html}
+#'   \url{https://mafft.cbrc.jp/alignment/software/index.html}
 #' @note \code{mafft} was last updated and tested to work with MAFFT 7.205. If 
 #'   you have problems getting the function to work with a newer version of 
 #'   MAFFT, please contact the package maintainer.
@@ -83,17 +84,20 @@
 #' @export
 
 mafft <- function(x, y, add, method = "auto", maxiterate = 0,
-                  op = 1.53, ep = 0.0, gt, options,
+                  op = 1.53, ep = 0.0, gt = NULL, options,
                   thread = -1, exec, quiet, file){
   
   ## CHECKS and DEFINITIONS
   ## ----------------------
+  if (missing(exec)) exec <- "/usr/local/bin/mafft"
+  # info <- system2(command = exec, args = "--help", stdout = FALSE)
+
   if (!inherits(x, c("DNAbin", "AAbin")))
     stop("'x' is not of class 'DNAbin' or 'AAbin'")
   os <- .Platform$OS
   if (missing(quiet)) quiet <- TRUE
   qut <- ifelse(quiet, " --quiet ", " ")
-  if (missing(exec)) exec <- "/usr/local/bin/mafft"
+  
   maxiterate <- match.arg(as.character(maxiterate), c("0", "2", "1000"))
   if (is.matrix(x)) x <- as.list(x)
   
@@ -109,7 +113,7 @@ mafft <- function(x, y, add, method = "auto", maxiterate = 0,
   
   ## guide tree
   ## ----------
-  if (missing(gt)){
+  if (is.null(gt)){
     gt <- ""
   } else {
     if (!inherits(gt, "phylo"))
